@@ -23,25 +23,20 @@
 #include "recentlyused.h"
 
 #include <QCoreApplication>
-#include <QDBusInterface>
-#include <QFileInfo>
 #include <QUrl>
 #include <QUrlQuery>
-#include <QString>
 
-#include <KRecentDocument>
-#include <KDirWatch>
-#include <KDesktopFile>
 #include <KIO/Job>
 #include <KLocalizedString>
-#include <KProtocolManager>
-
-#include <stdio.h>
 
 #include <KActivities/Stats/Cleaning>
 #include <KActivities/Stats/ResultModel>
 #include <KActivities/Stats/Terms>
 
+#ifdef Q_OS_WIN
+#include <sys/stat.h>
+#endif
+
 namespace KAStats = KActivities::Stats;
 
 using namespace KAStats;
@@ -231,13 +226,18 @@ void RecentlyUsed::listDir(const QUrl &url)
 KIO::UDSEntry RecentlyUsed::udsEntryForRoot(const QString &dirName, const QString &iconName)
 {
     KIO::UDSEntry uds;
-    uds.reserve(6);
+    uds.reserve(7);
     uds.fastInsert(KIO::UDSEntry::UDS_NAME, dirName);
     uds.fastInsert(KIO::UDSEntry::UDS_DISPLAY_NAME, dirName);
     uds.fastInsert(KIO::UDSEntry::UDS_DISPLAY_TYPE, dirName);
     uds.fastInsert(KIO::UDSEntry::UDS_ICON_NAME, iconName);
     uds.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
     uds.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("inode/directory"));
+#ifdef Q_OS_WIN
+    uds.fastInsert(KIO::UDSEntry::UDS_ACCESS, _S_IREAD );
+#else
+    uds.fastInsert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IXUSR );
+#endif
     return uds;
 }
 
